@@ -4,9 +4,7 @@
 package main
 
 import (
-	"bytes"
 	"fmt"
-	"io"
 	"log"
 	"os"
 	"os/exec"
@@ -17,7 +15,7 @@ import (
 )
 
 type model struct {
-	term      *tcellterm.Terminal
+	term      *tcellterm.VT
 	s         tcell.Screen
 	termView  views.View
 	title     *views.TextBar
@@ -25,78 +23,83 @@ type model struct {
 }
 
 // Update is the main event handler. It should only be called by the main thread
-func (m *model) Update(ev tcell.Event) bool {
+func (m *model) Update(ev tcell.Event) {
 	switch ev := ev.(type) {
 	case *tcell.EventKey:
 		switch ev.Key() {
 		case tcell.KeyCtrlC:
 			m.term.Close()
-			m.s.Clear()
 			m.s.Fini()
-			return true
+			return
 		}
 		if m.term != nil {
-			return m.term.HandleEvent(ev)
+			m.term.HandleEvent(ev)
 		}
+		m.term.Draw()
+		m.s.Show()
 	case *tcell.EventResize:
 		if m.term != nil {
 			m.termView.Resize(0, 2, -1, -1)
-			m.term.Resize()
+			m.term.Resize(m.termView.Size())
 		}
 		m.titleView.Resize(0, 0, -1, 2)
 		m.title.Resize()
+		m.title.Draw()
+		m.term.Draw()
 		m.s.Sync()
-		return true
-	case *views.EventWidgetContent:
+		return
+	case *tcellterm.EventRedraw:
 		m.term.Draw()
 		m.title.Draw()
 
-		vis, x, y, style := m.term.GetCursor()
+		row, col, style, vis := m.term.Cursor()
 		if vis {
-			m.s.ShowCursor(x, y+2)
 			m.s.SetCursorStyle(style)
+			m.s.ShowCursor(col, row+2)
+
 		} else {
 			m.s.HideCursor()
 		}
 		m.s.Show()
-		return true
+		return
 	case *tcellterm.EventClosed:
 		m.s.Clear()
 		m.s.Fini()
-		return true
+		return
 	case *tcell.EventPaste:
-		return m.term.HandleEvent(ev)
+		m.term.HandleEvent(ev)
+		return
 	case *tcell.EventMouse:
 		// Translate the coordinates to our global coordinates (y-2)
 		x, y := ev.Position()
 		if y-2 < 0 {
 			// Event is outside our view
-			return false
+			return
 		}
 		e := tcell.NewEventMouse(x, y-2, ev.Buttons(), ev.Modifiers())
-		return m.term.HandleEvent(e)
+		m.term.HandleEvent(e)
+		return
 	case *tcellterm.EventMouseMode:
 		m.s.EnableMouse(ev.Flags()...)
+	case *tcellterm.EventPanic:
+		m.s.Clear()
+		m.s.Fini()
+		fmt.Println(ev.Error)
 	}
-	return false
+	return
 }
 
 // HandleEvent is used to handle events from underlying widgets. Any events
 // which redraw must be executed in the main goroutine by posting the event back
 // to tcell
-func (m *model) HandleEvent(ev tcell.Event) bool {
+func (m *model) HandleEvent(ev tcell.Event) {
 	m.s.PostEvent(ev)
-	return false
 }
 
 func main() {
+	f, _ := os.Create("recording.log")
+	log.SetOutput(f)
 	var err error
-	f, _ := os.Create(".log")
-	defer f.Close()
-	logbuf := bytes.NewBuffer(nil)
-	log.SetOutput(io.MultiWriter(f, logbuf))
-	log.SetFlags(log.LstdFlags | log.Lshortfile)
-
 	m := &model{}
 	m.s, err = tcell.NewScreen()
 	if err != nil {
@@ -118,20 +121,16 @@ func main() {
 	)
 
 	m.titleView = views.NewViewPort(m.s, 0, 0, -1, 2)
-	m.title.Watch(m)
 	m.title.SetView(m.titleView)
 
-	recorder, err := os.Create("recording.log")
-	if err != nil {
-		fmt.Fprintf(os.Stderr, "%v\n", err)
-		os.Exit(1)
-	}
-	defer recorder.Close()
-
 	m.termView = views.NewViewPort(m.s, 0, 2, -1, -1)
-	m.term = tcellterm.New(tcellterm.WithWriter(recorder))
-	m.term.Watch(m)
-	m.term.SetView(m.termView)
+	// m.term = tcellterm.New(tcellterm.WithWriter(recorder))
+	// m.term.Watch(m)
+	m.term = tcellterm.New()
+	m.term.SetSurface(m.termView)
+	m.term.Attach(m.HandleEvent)
+	m.term.Logger = log.New(f, "", log.Flags())
+	m.s.EnableMouse()
 
 	cmd := exec.Command(os.Getenv("SHELL"))
 	err = m.term.Start(cmd)
@@ -145,5 +144,4 @@ func main() {
 		}
 		m.Update(ev)
 	}
-	os.Stdout.Write(logbuf.Bytes())
 }
